#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['acanban', 'acanban.static']

package_data = \
{'': ['*']}

package_dir = \
{'': 'src'}

install_requires = \
['appdirs', 'hypercorn', 'quart-trio']

setup(name='acanban',
      version='0.0.1',
      description='Academic Kanban',
      author='Ngô Ngọc Đức Huy',
      author_email='duchuy29092000@gmail.com',
      url='https://Huy-Ngo.github.io/acanban',
      packages=packages,
      package_data=package_data,
      package_dir=package_dir,
      install_requires=install_requires,
      python_requires='>=3.7',
     )
